
{*******************************************************}
{                                                       }
{  Name:  TPDECL.PAS                                    }
{                                                       }
{   GPIB Interface Unit for Turbo Pascal                }
{                                                       }
{ (c) Copyright 1992-1997 NATIONAL INSTRUMENTS          }
{ All Rights Reserved                                   }
{                                                       }
{*******************************************************}


unit TPDECL;

{$D+,S+,L+}


interface


const
       { GPIB Commands codes }
   GTL = $01;
   SDC = $04;
   PPC = $05;
   GET = $08;
   TCT = $09;
   LLO = $11;
   DCL = $14;
   PPU = $15;
   SPE = $18;
   SPD = $19;
   UNL = $3f;
   UNT = $5f;
   PPE = $60;
   PPD = $70;


{ Bit specifiers for IBSTA status variable and wait mask  }
   ERR  = $8000;   { Error                           }
   TIMO = $4000;   { Timeout                         }
   EEND = $2000;   { EOI or EOS detected             }
   SRQI = $1000;   { SRQ detected by CIC             }
   RQS  = $0800;   { Device needs service            }
   SPOLL= $0400;   { Board has been serially polled  }
   EVENT= $0200;   { An event has occured            }
   CMPL = $0100;   { I/O completed                   }
   LOK  = $0080;   { Local lockout state             }
   REM  = $0040;   { Remote state                    }
   CIC  = $0020;   { Controller-in-Charge            }
   ATN  = $0010;   { Attention asserted              }
   TACS = $0008;   { Talker active                   }
   LACS = $0004;   { Listener active                 }
   DTAS = $0002;   { Device trigger state            }
   DCAS = $0001;   { Device clear state              }



{ System error codes - returned in IBERR variable }
   EDVR  = 0;     { DOS error                                }
   ECIC  = 1;     { Board must be CIC                        }
   ENOL  = 2;     { No listeners detected                    }
   EADR  = 3;     { Board not addressed correctly            }
   EARG  = 4;     { Invalid argument specified               }
   ESAC  = 5;     { Board should be system controller        }
   EABO  = 6;     { I/O operation aborted                    }
   ENEB  = 7;     { Invalid interface board specified        }
   EOIP  = 10;    { I/O operation already running            }
   ECAP  = 11;    { Board does not have requested capability }
   EFSO  = 12;    { Error returned from file system          }
   EBUS  = 14;    { Command error on bus                     }
   ESTB  = 15;    { Serial poll responde byte lost           }
   ESRQ  = 16;    { SRQ is still asserted                    }
   ETAB  = 20;    { No device responding with ETAB           }
   EINT  = 247;   { No interrupt configured on baord         }
   ECFG  = 252;   { Board type doesn't match GPIB.CFG        }


{ EOS mode bits   }
   BIN  = $1000;
   XEOS = $0800;
   REOS = $0400;

{ Timeout values and meanings }
   TNONE  =  0;   { No timeout         }
   T10us  =  1;   { 10   microseconds  }
   T30us  =  2;   { 30   microseconds  }
   T100us =  3;   { 100  microseconds  }
   T300us =  4;   { 300  microseconds  }
   T1ms   =  5;   { 1    milliseconds  }
   T3ms   =  6;   { 3    milliseconds  }
   T10ms  =  7;   { 10   milliseconds  }
   T30ms  =  8;   { 30   milliseconds  }
   T100ms =  9;   { 100  milliseconds  }
   T300ms = 10;   { 300  milliseconds  }
   T1s    = 11;   { 1    seconds  }
   T3s    = 12;   { 3    seconds  }
   T10s   = 13;   { 10   seconds  }
   T30s   = 14;   { 30   seconds  }
   T100s  = 15;   { 100  seconds  }
   T300s  = 16;   { 300  seconds  }
   T1000s = 17;   { 1000 seconds  }


{ IBLN contants }
   NO_SAD  = 0;     { No secondary address    }
   ALL_SAD = -1;    { All secondary addresses }


{ Miscellaneous  }
   S   = $08;           { parallel poll bit  }
   LF  = $0a;           { linefeed character }
   NOADDR    = $FFFF;   { Terminator for address list    }
   NULLend   = 0;       { Send() EOTMODE - Do nothing at the end of a transfe   }
   NLend     = 1;       { Send() EOTMODE - Send NL with EOI after a transfer.   }
   DABend    = 02;      { Send() EOTMODE - Send EOI with the last DAB. }
   STOPend   = $0100;   { Receive() termination }
   EventDTAS = 1;       { used by IBEVENT()   }
   EventDCAS = 2;       { used by IBEVENT()   }


{  These constants are used with ibconfig() to specify one of the
    configurable options. }
   IbcPAD =           $0001;    { Primary Address                  }
   IbcSAD =           $0002;    { Secondary Address                }
   IbcTMO =           $0003;    { Timeout                          }
   IbcEOT =           $0004;    { Send EOI with last byte          }
   IbcPPC =           $0005;    { Parallel Poll configure          }
   IbcREADDR =        $0006;    { Repeat addressing                }
   IbcAUTOPOLL =      $0007;    { Disable automatic serial polling }
   IbcCICPROT =       $0008;    { Use CIC Protocol                 }
   IbcIRQ =           $0009;    { Interrupt level (or 0 for NONE)  }
   IbcSC =            $000A;    { Board is ssystem controller      }
   IbcSRE =           $000B;    { Assert SRE for device calls      }
   IbcEOSrd =         $000C;    { Terminate read on EOS            }
   IbcEOSwrt =        $000D;    { Send EOI with EOS                }
   IbcEOScmp =        $000E;    { Use 7 or 8-bit compare on EOS    }
   IbcEOSchar =       $000F;    { EOS character                    }
   IbcPP2 =           $0010;    { Use PP Mode 2                    }
   IbcTIMING =        $0011;    { Normal, High or VeryHighspeed    }
   IbcDMA =           $0012;    { DMA channle (or 0 for NONE)      }
   IbcReadAdjust =    $0013;    { Swap bytes on read               }
   IbcWriteAdjust =   $0014;    { Swap bytes on write              }
   IbcEventQueue =    $0015;    { Use event queue                  }
   IbcSPollBit =      $0016;    { Serial poll bit used             }
   IbcSendLLO =       $0017;    { Automatically send LLO           }
   IbcSPollTime =     $0018;    { Serial polls timeout             }
   IbcPPollTime =     $0019;    { Parallel poll timeout            }
   IbcEndBitIsNormal = $001A;   { Don't set END bit on EOS.        }
   IbcBNA =           $0200;    { A device's access board.         }
   IbcBaseAddr =      $0201;    { A GPIB board's base I/O address. }

   { CBI Config Items - don't exist in NI software }
   IbcBoardType =     $0300;    { Board type                       }
   IbcChipType =      $0301;    { Chip type                        }
   IbcSlotNum =       $0302;    { Slot Number                      }
   IbcPCIIndex =      $0303;    { PCI Index                        }
   IbcBaseAdr2 =      $0304;    { 2nd Base address for PCI board   }
   IbcUseFIFOs =      $0305;    { When to use FIFOs                }


{  These constants are used with ibask() to specify one of the
    configurable options. }
   IbaPAD =           $0001;    { Primary Address                  }
   IbaSAD =           $0002;    { Secondary Address                }
   IbaTMO =           $0003;    { Timeout                          }
   IbaEOT =           $0004;    { Send EOI with last byte          }
   IbaPPC =           $0005;    { Parallel Poll configure          }
   IbaREADDR =        $0006;    { Repeat addressing                }
   IbaAUTOPOLL =      $0007;    { Disable automatic serial polling }
   IbaCICPROT =       $0008;    { Use CIC Protocol                 }
   IbaIRQ =           $0009;    { Interrupt level (or 0 for NONE)  }
   IbaSC =            $000A;    { Board is ssystem controller      }
   IbaSRE =           $000B;    { Assert SRE for device calls      }
   IbaEOSrd =         $000C;    { Terminate read on EOS            }
   IbaEOSwrt =        $000D;    { Send EOI with EOS                }
   IbaEOScmp =        $000E;    { Use 7 or 8-bit compare on EOS    }
   IbaEOSchar =       $000F;    { EOS character                    }
   IbaPP2 =           $0010;    { Use PP Mode 2                    }
   IbaTIMING =        $0011;    { Normal, High or VeryHighspeed    }
   IbaDMA =           $0012;    { DMA channle (or 0 for NONE)      }
   IbaReadAdjust =    $0013;    { Swap bytes on read               }
   IbaWriteAdjust =   $0014;    { Swap bytes on write              }
   IbaEventQueue =    $0015;    { Use event queue                  }
   IbaSPollBit =      $0016;    { Serial poll bit used             }
   IbaSendLLO =       $0017;    { Automatically send LLO           }
   IbaSPollTime =     $0018;    { Serial polls timeout             }
   IbaPPollTime =     $0019;    { Parallel poll timeout            }
   IbaEndBitIsNormal = $001A;   { Don't set END bit on EOS.        }
   IbaBNA =           $0200;    { A device's access board.         }
   IbaBaseAddr =      $0201;    { A GPIB board's base I/O address. }

   { CBI Config Items - don't exist in NI software }
   IbaBoardType =     $0300;    { Board type                       }
   IbaChipType =      $0301;    { Chip type                        }
   IbaSlotNum =       $0302;    { Slot Number                      }
   IbaPCIIndex =      $0303;    { PCI Index                        }
   IbaBaseAdr2 =      $0304;    { 2nd Base address for PCI board   }
   IbaUseFIFOs =      $0305;    { When to use FIFOs                }


{ These bits specify which lines can be monitored by IBLINES }
  ValidDAV = $0001;
  ValidNDAC = $0002;
  ValidNRFD = $0004;
  ValidIFC = $0008;
  ValidREN = $0010;
  ValidSRQ = $0020;
  ValidATN = $0040;
  ValidEOI = $0080;

{ These bits specify the current state of each GPIB line }
  BusDAV = $0100;
  BusNDAC = $0200;
  BusNRFD = $0400;
  BusIFC = $0800;
  BusREN = $1000;
  BusSRQ = $2000;
  BusATN = $4000;
  BusEOI = $8000;



{ String lengths for buffers                              }
   nbufsize = 32;      { Max length of GPIB device names  }
   flbufsize = 50;     { Max length of filenames          }
   cbufsize =  255;    { Size of read/write buffer        }


{***************************************************************************}

Type
       nbuf  = array[1..nbufsize]  of char;   {  GPIB device name }
       cbuf  = array[1..cbufsize] of char;    {  rd/wrt buffer    }
       flbuf = array[1..flbufsize] of char;   {  filename         }



{***************************************************************************}

var
{ GPIB global  variables }
  ibsta: word;
  iberr: word;
  ibcnt: word;
  ibcntl: Longint;

{  Instances of variables provided for compatability }
    bname  : nbuf;     (* board name buffer                 *)
    bdname : nbuf;     (* board or device name buffer       *)
    flname : flbuf;    (* filename buffer                    *)



{***************************************************************************}

{ GPIB function prototypes }
procedure ibask    (board:Integer; item:Integer; var value:Integer);
procedure ibbna    (device:Integer; var boardname:nbuf);
procedure ibcac    (device:Integer; sync:Integer);
procedure ibclr    (device:Integer);
procedure ibcmd    (board:Integer; var cmnd; bytecount:Longint);
procedure ibcmda   (board:Integer; var cmnd; bytecount:Longint);
procedure ibconfig (board:Integer; item:Integer; value:Integer);
function  ibdev    (boardindex:Integer; pad:Integer; sad:Integer;
                    timeout:Integer; eot:Integer; eos:Integer):Integer;
procedure ibdma    (device:Integer; dma:Integer);
procedure ibeos    (boarddev:Integer; eos:Integer);
procedure ibeot    (boarddev:Integer; eot:Integer);
procedure ibevent  (board:Integer; var event:Integer);
function  ibfind   (var name:nbuf):Integer;
procedure ibgts    (board:Integer; handshake:Integer);
procedure ibinit   (board:Integer);
procedure ibist    (board:Integer; Statusbit:Integer);
procedure iblines  (board:Integer; var clines:Integer);
procedure ibln     (board:Integer; pad:Integer; sad:Integer; var listenflag:Integer);
procedure ibloc    (boarddev:Integer);
procedure ibonl    (boarddev:Integer; online:Integer);
procedure ibpad    (boarddev:Integer; address:Integer);
procedure ibpct    (device:Integer);
procedure ibppc    (board:Integer; command:Integer);
procedure ibrd     (boarddev:Integer; var readstr; bytecount:Longint);
procedure ibrda    (boarddev:Integer; var readstr; bytecount:Longint);
procedure ibrdf    (boarddev:Integer; var filename:flbuf);
procedure ibrpp    (boarddev:Integer; var response:Byte);
procedure ibrsc    (board:Integer; control:Integer);
procedure ibrsp    (device:Integer; var serialpollbyte:Byte);
procedure ibrsv    (boarddev:Integer; statusbyte:Integer);
procedure ibsad    (boarddev:Integer; address:Integer);
procedure ibsic    (board:Integer);
procedure ibsre    (board:Integer; ren:Integer);
procedure ibstop   (boarddev:Integer);
procedure ibtmo    (boarddev:Integer; timeout:Integer);
procedure ibtrg    (device:Integer);
procedure ibwait   (boarddev:Integer; mask:word);
procedure ibwrt    (boarddev:Integer; var writestr; bytecount:Longint);
procedure ibwrta   (boarddev:Integer; var writestr; bytecount:Longint);
procedure ibwrtf   (boarddev:Integer; var filename:flbuf);


implementation

{$L TPIB}
   procedure ibask    (board:Integer; item:Integer; var value:Integer); external;
   procedure ibbna    (Device:Integer; var BoardName:nbuf); external;
   procedure ibcac    (Device:Integer; sync:Integer); external;
   procedure ibclr    (Device:Integer); external;
   procedure ibcmd    (Board:Integer; var cmnd; ByteCount:Longint); external;
   procedure ibcmda   (Board:Integer; var cmnd; ByteCount:Longint); external;
   procedure ibconfig (Board:Integer; Item:Integer; Value:Integer); external;
   function  ibdev    (BoardIndex:Integer; pad:Integer; sad:Integer;
                       Timeout:Integer; EOT:Integer; EOS:Integer):Integer; external;
   procedure ibdma    (Device:Integer; DMA:Integer); external;
   procedure ibeos    (BoardDev:Integer; EOS:Integer); external;
   procedure ibeot    (BoardDev:Integer; EOT:Integer); external;
   procedure ibevent  (board:Integer; var event:Integer); external;
   function  ibfind   (var Name:nbuf):Integer; external;
   procedure ibgts    (Board:Integer; Handshake:Integer); external;
   procedure ibinit   (Board:Integer); external;
   procedure ibist    (Board:Integer; Statusbit:Integer); external;
   procedure iblines  (Board:Integer; var clines:Integer); external;
   procedure ibln     (board:Integer; pad:Integer; sad:Integer; var listenflag:Integer); external;
   procedure ibloc    (BoardDev:Integer); external;
   procedure ibonl    (BoardDev:Integer; OnLine:Integer); external;
   procedure ibpad    (BoardDev:Integer; Address:Integer); external;
   procedure ibpct    (Device:Integer); external;
   procedure ibppc    (Board:Integer; Command:Integer); external;
   procedure ibrd     (BoardDev:Integer; var ReadStr; ByteCount:Longint); external;
   procedure ibrda    (BoardDev:Integer; var ReadStr; ByteCount:Longint); external;
   procedure ibrdf    (BoardDev:Integer; var FileName:flbuf); external;
   procedure ibrpp    (BoardDev:Integer; var Response:Byte); external;
   procedure ibrsc    (Board:Integer; Control:Integer); external;
   procedure ibrsp    (Device:Integer; var SerialPollByte:Byte); external;
   procedure ibrsv    (BoardDev:Integer; StatusByte:Integer); external;
   procedure ibsad    (BoardDev:Integer; Address:Integer); external;
   procedure ibsic    (Board:Integer); external;
   procedure ibsre    (Board:Integer; Ren:Integer); external;
   procedure ibstop   (BoardDev:Integer); external;
   procedure ibtmo    (BoardDev:Integer; Timeout:Integer); external;
   procedure ibtrg    (Device:Integer); external;
   procedure ibwait   (BoardDev:Integer; Mask:word); external;
   procedure ibwrt    (BoardDev:Integer; var WriteStr; ByteCount:Longint); external;
   procedure ibwrta   (BoardDev:Integer; var WriteStr; ByteCount:Longint); external;
   procedure ibwrtf   (BoardDev:Integer; var FileName:flbuf); external;



var
   LoopCount: Integer;

begin
   ibsta := 0;
   iberr := 0;
   ibcnt := 0;

   for LoopCount:=1 to nbufsize do   { Clear buffers }
      begin
      bname[LoopCount] := ' ';
      end;

   for LoopCount:=1 to flbufsize do
      flname[LoopCount]:=' ';



end
.


