Unit UGPIB291;
{V2.91, 11.04.01}

Interface

Var
  GPIBBusTalkInProgress : boolean;


Procedure SetCurrent(Current: Real);
Procedure DirectStop;
Function InitGpibBus : boolean;
Procedure DeInitGpibBus;
Procedure GPIBReadTemp(var Temps:String); {Reads surface Temperature}
Procedure GPIBInitReadCable_shunt;
Procedure GPIBReadCable_shunt(var CableS,ShuntS:String); {Reads Volt. drop Cable + Shunt Temperature}
Procedure GPIBReadExtraTemp(var ExtraTempSVec:Array of String); {Reads multiple Temperatures}
Procedure GPIBReadCurrentByPower(var Currents:String); {Reads Power's opinion of PresentCurrent}

Implementation

Uses
  TPDecl,UScrKeyb, CRT;

Const
  EOS : Char= #10; {Sets LF as Line End Character}
  brdS : String ='GPIB0';
  DMMS : String ='prema1';
  PowerS : String ='power';

Var
  brd,power,dmm:integer; {Device Handles}
  mport: String;


{************************************************************************}
{                                                                        }
{  Name:         PrintErrors                                             }
{  Description:  This procedure prints an error message followed by the  }
{                values of the global staus variables - IBSTA, IBERR,    }
{                and IBCNT.  For IBSTA it prints the name of every bit   }
{                that is set.  For IBERR it prints the mnemonic for the  }
{                error code.                                             }
{                                                                        }
{************************************************************************}

procedure PrintErrors (message:string);
Var i:integer;
begin
   Box;
   GotoXY(sright+2,sdown+1);
   write (message);                            { Print error message }

   GotoXY(sright+2,sdown+2);
   write ('   IBSTA=', ibsta,' <');              { Print IBSTA value }
   if ibsta and ERR  <> 0 then write (' ERR');
   if ibsta and TIMO <> 0 then write (' TIMO');  { Print names of set bits }
   if ibsta and EEND <> 0 then write (' END');
   if ibsta and SRQI <> 0 then write (' SRQI');
   if ibsta and RQS  <> 0 then write (' RQS');
   if ibsta and SPOLL <> 0 then write (' SPOLL');
   if ibsta and EVENT <> 0 then write (' EVENT');
   if ibsta and CMPL <> 0 then write (' CMPL');
   if ibsta and LOK  <> 0 then write (' LOK');
   if ibsta and REM  <> 0 then write (' REM');
   if ibsta and CIC  <> 0 then write (' CIC');
   if ibsta and ATN  <> 0 then write (' ATN');
   if ibsta and TACS <> 0 then write (' TACS');
   if ibsta and LACS <> 0 then write (' LACS');
   if ibsta and DTAS <> 0 then write (' DTAS');
   if ibsta and DCAS <> 0 then write (' DCAS');
   write( ' >');

   GotoXY(sright+2,sdown+3);
   write('   IBERR=', iberr);                      { Print IBERR value }
   if iberr = EDVR then write (' EDVR <DOS Error>');   { Print mnenmonic }
   if iberr = ECIC then write (' ECIC <Not CIC>');
   if iberr = ENOL then write (' ENOL <No Listener>');
   if iberr = EADR then write (' EADR <Address error>');
   if iberr = EARG then write (' EARG <Invalid argument>');
   if iberr = ESAC then write (' ESAC <Not Sys Ctrlr>');
   if iberr = EABO then write (' EABO <Op. aborted>');
   if iberr = ENEB then write (' ENEB <No GPIB board>');
   if iberr = EOIP then write (' EOIP <Async I/O in prg>');
   if iberr = ECAP then write (' ECAP <No capability>');
   if iberr = EFSO then write (' EFSO <File sys. error>');
   if iberr = EBUS then write (' EBUS <Command error>');
   if iberr = ESTB then write (' ESTB <Status byte lost>');
   if iberr = ESRQ then write (' ESRQ <SRQ stuck on>');
   if iberr = ETAB then write (' ETAB <Table Overflow>');
   if iberr = ECFG then write (' ECFG <Incorrect board>');

   GotoXY(sright+2,sdown+4);
   write('   IBCNT=', ibcnt);
   Snd(False);
   GotoXY(sright+2,sdown+6);
   write('Press key to continue or Wait');
   While Keypressed do Readkey;
   For i := 1 to 15 do
     begin
       Delay(200);
       If Keypressed then Break;
     end;
   While Keypressed do Readkey;
end;

Procedure MKnbuf(s:string; var nb:nbuf);
Var
  StrLen,i:LongInt;
Begin
  StrLen := length (s);
  for i:=1 to nbufsize do              { Copy the name into char array }
      begin
      if i <= StrLen then
         nb[i] := s[i]
      else
         nb[i] := ' ';
      end;
End;



{************************************************************************}
{                                                                        }
{  Name:         WriteCommand                                            }
{  Arguments:    DevHandle - handle of opened GPIB device                }
{                CommandStr - command string to write to device          }
{  Description:  Writes a string to a GPIB device and checks for errors  }
{                                                                        }
{************************************************************************}

procedure WriteCommand (DevHandle:integer; CommandStr:string);

var
   StrLen,i:integer;
   WriteBuffer:cbuf;

begin
   if GpibBusTalkInProgress then
     Begin
       PrintErrors ('Overlapping Read');
       Sound(100);
       while GpibBusTalkInProgress do delay(10);
       NoSound;
     end;
   GPIBBusTalkInProgress:=True;
   StrLen := length (CommandStr);             {  Copy from string to buffer }
   for i:=1 to StrLen do
      WriteBuffer[i] := CommandStr[i];
   WriteBuffer[StrLen+1]:=EOS;
   Kb_Set_Led(Scrl,true);
   ibwrt (DevHandle, WriteBuffer, StrLen+1);           {Write to GPIB  }
   Kb_Set_Led(Scrl,False);
   GPIBBusTalkInProgress:=False;
   if (ibcnt<>StrLen+1) or (ibsta and ERR <> 0) then  { Check for errors}
      PrintErrors ('   IBWRT failed while writing '+CommandStr);
end;




{************************************************************************}
{                                                                        }
{  Name:         ReadValue                                               }
{  Arguments:    DevHandle - handle of opened GPIB device                }
{                buffer - buffer to read data into                       }
{                bufsize - size of buffer                                }
{  Description:  Reads from a GPIB device                                }
{                                                                        }
{************************************************************************}


procedure ReadValue (DevHandle:integer; var ReadStr:string);

var
   ReadBuffer:cbuf;
   i:integer;

begin
   ReadStr:='';
   if GpibBusTalkInProgress then
     Begin
       PrintErrors ('Overlapping Read');
       Sound(100);
       while GpibBusTalkInProgress do delay(10);
       NoSound;
     end;
   GPIBBusTalkInProgress:=True;
   Kb_Set_Led(Numl,true);
   ibrd (DevHandle, ReadBuffer, cbufsize);     { Read from GPIB }
   Kb_Set_Led(Numl,false);
   GPIBBusTalkInProgress:=False;
   if (ibcnt = 0) or (ibsta and ERR <> 0) then { Check for errors }
     PrintErrors ('IBRD failed')
   else
     begin
      If ReadBuffer[ibcnt] <> EOS then PrintErrors('IBRD String does not contain EOS Byte');
      for i:=1 to ibcnt-1 do
         ReadStr:=ReadStr+ReadBuffer[i];          { Copy from buffer to string }
      end;
end;

{-----------------------------------------------------------------------------------------}


Var
  DTemp, DShunt, DCable, DPower:integer;


Procedure GPIBReadTemp(var Temps:String); {Reads surface Temperature}
Begin
  If MPort <> 'mo' then
    Begin
      MPort:='mo';
      WriteCommand(dmm,MPort);
      WriteCommand(dmm,'TCR1T3S0');
      Delay(500);
    end;
  ReadValue(dmm,temps);
  If Pos('TC',TempS) <>13 then Begin PrintErrors('Could not read Temperature!!'); end
  else
    begin
      Delete(tempS,13,100);
    end;
End;

Procedure GPIBReadExtraTemp(var ExtraTempSVec:Array of String); {Reads multiple Temperatures}
Var j:integer;
Begin
  For j:=0 to 4 do ExtraTempSVec[j] :='';
  For j:=0 to 4 do
    Begin
      MPort:='m'+Chr(48+5+j);             {'0'+5+j}
      WriteCommand(dmm,MPort);
      WriteCommand(dmm,'TCR1T1S0');
      Delay(110);
      WriteCommand(dmm,'T4S1');
      Delay(1000);
      ReadValue(dmm,ExtratempSVec[j]);
      If Pos('TC',ExtratempSVec[j]) <>13 then Begin PrintErrors('Could not read Extra Temperature!!'); end
        else
      begin
        Delete(ExtratempSVec[j],13,100);
      end;
    End;
End;


Procedure GPIBReadCable_shunt(var CableS,ShuntS:String); {Reads Volt. drop Cable + Shunt Temperature}
Begin
  MPort:='m3';
  WriteCommand(DMM,mport);
  WriteCommand(DMM,'VDT1A1');
  Delay(2000);
  WriteCommand(DMM,'T5S1');
  Delay(5100);
  ReadValue(dmm,Cables);
  If Pos('VD',CableS) <>13 then Begin PrintErrors('Could not read Cable Voltage Drop!!'); end
  else
    begin
      Delete(CableS,13,100);
    end;
  WriteCommand(DMM,'VDT1A0R1S0');
  MPort:='m1';
  WriteCommand(DMM,mport);
  Delay(200);
  WriteCommand(DMM,'T5S1');
  Delay(5100);
  ReadValue(dmm,Shunts);
  If Pos('VD',ShuntS) <>13 then Begin PrintErrors('Could not read Shunt Voltage Drop!!'); end
  else
    begin
      Delete(ShuntS,13,100);
    end;
End;

Procedure GPIBInitReadCable_shunt;
Begin
End;


Procedure SetCurrent(Current: Real);
Var
  CurrentS, rcs : String;
  ec:integer;
  cc:real;

Begin
  Str(Current:10:2,CurrentS);
  While Pos(' ',CurrentS) > 0 do
    Delete(CurrentS,Pos(' ',CurrentS),1);
  CurrentS:='Current '+CurrentS;
  WriteCommand(Power,CurrentS);
  WriteCommand(power,'Current?');
  ReadValue(power,rcs);
  {Delete(rcs,1,1);}
  Val(rcs,cc,ec);
  If (cc <> Current) or (ec <> 0) then Begin PrintErrors('Could not set >'+CurrentS+'< at POWER-Device!!'); end;
End;

Procedure GPIBReadCurrentByPower(var Currents:String); {Reads Power's opinion of PresentCurrent}

Begin
  WriteCommand(power,'Measure:Current?');
  ReadValue(power,CurrentS);
  {If Pos(CurrentS,'A') > 0 then
    Delete(CurrentS,Pos(CurrentS,'A'),100)
  else Begin PrintErrors('Could not MEASURE Current at POWER-Device!!'); end;}
End;


Function InitGpibBus :boolean;
Var
 nb : nbuf;
 VoltageS, IDS, Temps: String;
 InitGpibBusd: boolean;

Begin
  GPIBBusTalkInProgress:=False;
  InitGpibBusD:=true;
  Mknbuf(brds,nb);
  brd:=IbFind(nb);
  If (IBErr <> 0) or (brd < 0) then begin PrintErrors('IBFind(board) failed'); InitGpibBusd:=false; end;
  IBInit(brd);
  If IBErr <> 0 then Begin PrintErrors('IBInit board failed'); InitGpibBusd:=false; end;
  IBCac(brd,1); {Become active Controler}
  If IBErr <> 0 then Begin PrintErrors('IBCAC board (become active controler and assert ATN) failed');
                           InitGpibBusd:=false; end;

  Mknbuf(powers,nb);
  power:=IBFind(nb);
  If (IBErr <> 0) or (brd < 0) then Begin PrintErrors('IBFind(power) failed'); InitGpibBusd:=false; end;
  IBClr(power);
  WriteCommand(power,'Current 0');
  If IBErr <> 0 then InitGpibBusd:=false;
  WriteCommand(power,'Voltage 18.0');
  If IBErr <> 0 then InitGpibBusd:=false;
  WriteCommand(power,'Voltage?');
  If IBErr <> 0 then InitGpibBusd:=false;
  ReadValue(power,VoltageS);
  If IBErr <> 0 then InitGpibBusd:=false;
  If Pos('18',VoltageS) =0 then Begin PrintErrors('Could not set / read Voltage at POWER-Device!!');
                                          InitGpibBusd:=false; end;

  Mknbuf(dmms,nb);
  dmm:=IBFind(nb);
  If (IBErr <> 0) or (brd < 0) then Begin PrintErrors('IBFind(DMM) failed'); InitGpibBusd:=false; end;
  IBClr(dmm);
  WriteCommand(dmm,'VDR3A0T5L1Q0S1');
  If IBErr <> 0 then InitGpibBusd:=false;
  WriteCommand(dmm,'ID?');
  If IBErr <> 0 then InitGpibBusd:=false;
  ReadValue(dmm,IDS);
  If IBErr <> 0 then InitGpibBusd:=false;
  If Pos('DVM6001/SC',IDS) =0 then Begin PrintErrors('Could not set / read DMM-Device!!');
                                                  InitGpibBusd:=false; end;

  If InitGpibBusD then GPIBReadTemp(Temps);

  GPIBBusTalkInProgress:=False;

  InitGpibBus:=InitGpibBusD
End;

Procedure DeInitGpibBus;
Begin
  GPIBBusTalkInProgress:=True;;
  {IBLoc(power); Go to Local}
  IBClr(power);
  IBLoc(dmm); {Go to Local}
  IBGTS(brd,0); {Go to standby}
  GPIBBusTalkInProgress:=False;
End;

Procedure DirectStop;
Begin
  GPIBBusTalkInProgress:=True;;
  IBClr(power);
  GPIBBusTalkInProgress:=False;
end;

END.